| plot | R Documentation |
deepgp packageActs on a gp, gpvec, dgp2, dgp2vec,
dgp3, or dgp3vec object.
Generates trace plots for outer log likelihood, length scale,
and nugget hyperparameters.
Generates plots of hidden layers for low dimensions or
monotonic warpings. Generates
plots of the posterior mean and estimated 90% prediction intervals for
one-dimensional inputs; generates heat maps of the posterior mean and
point-wise variance for two-dimensional inputs.
## S3 method for class 'gp'
plot(x, trace = NULL, predict = NULL, ...)
## S3 method for class 'gpvec'
plot(x, trace = NULL, predict = NULL, ...)
## S3 method for class 'dgp2'
plot(x, trace = NULL, hidden = NULL, predict = NULL, ...)
## S3 method for class 'dgp2vec'
plot(x, trace = NULL, hidden = NULL, predict = NULL, ...)
## S3 method for class 'dgp3'
plot(x, trace = NULL, hidden = NULL, predict = NULL, ...)
## S3 method for class 'dgp3vec'
plot(x, trace = NULL, hidden = NULL, predict = NULL, ...)
x |
object of class |
trace |
logical indicating whether to generate trace plots (default is
TRUE if the object has not been through |
predict |
logical indicating whether to generate posterior predictive
plot (default is TRUE if the object has been through |
... |
N/A |
|
logical indicating whether to generate plots of hidden layers (two or three layer only, default is FALSE) |
Trace plots are useful in assessing burn-in. If there are too
many hyperparameters to plot them all, then it is most useful to
visualize the log likelihood (e.g., plot(fit$ll, type = "l")).
In one dimension, hidden layer plots show 100 evenly distributed samples. In two dimensions (two layer only), hidden layer plots show 3 samples. Hidden layer plots are colored on a gradient - red lines represent earlier iterations and yellow lines represent later iterations - to help assess burn-in of the hidden layers.
# See ?fit_one_layer, ?fit_two_layer, or ?fit_three_layer
# for examples
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.