| to_vec | R Documentation |
Converts an object of class "gp", "dgp2", or "dgp3" to its Vecchia equivalent ("gpvec", "dgp2vec", or "dgp3vec").
to_vec(object, m = NULL, ord = NULL, cores = NULL)
object |
object from |
m |
size of Vecchia conditioning sets, defaults to the lower of 25 or maximum available |
ord |
optional ordering for Vecchia approximation, defaults to random |
cores |
number of cores to use for OpenMP parallelization. Defaults
to |
Creates and appends Vecchia-approximation objects to the provided fit. Defaults to random ordering and nearest neighbors conditioning. Useful for speeding up predictions when the testing size is large but the training size is small.
The same object, with x_approx, w_approx, and z_approx
appended (depending on the number of layers).
# See ?fit_one_layer for an example
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.